@@ -1,14 +1,14 @@
 # Copyright (c) 2016-2020 Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import asyncio
+import collections
 import json
 import logging
 import os
 import re
-import ssl
 import sys
 import tempfile
-from functools import partial
+from functools import partial, lru_cache
 from pathlib import Path
 from subprocess import PIPE, Popen
 from typing import Any, Dict, List, Optional, Tuple, Union
@@ -192,20 +192,20 @@ class EnvManager:
             # Set conda by default
             EnvManager._manager_exe = CONDA_EXE
             try:
-                which = "which"
+                cmd = ["which", "mamba"]
                 if sys.platform == "win32":
-                    which = "where"
+                    cmd = ["where", "mamba.exe"]
 
                 process = Popen(
-                    [which, "mamba"], stdout=PIPE, stderr=PIPE, encoding="utf-8"
+                    cmd, stdout=PIPE, stderr=PIPE, encoding="utf-8"
                 )
                 output, error = process.communicate()
 
                 if process.returncode != 0:
                     raise RuntimeError(error)
 
-                mamba_exe = output.strip() or "mamba"
-                
+                mamba_exe = output.splitlines()[0] or "mamba"
+
                 process = Popen(
                     [mamba_exe, "--version"],
                     stdout=PIPE,
@@ -233,6 +233,10 @@ class EnvManager:
 
         return EnvManager._manager_exe
 
+    @lru_cache()
+    def is_mamba(self):
+        return Path(self.manager).stem == "mamba"
+
     async def env_channels(
         self, configuration: Optional[Dict[str, Any]] = None
     ) -> Dict[str, Dict[str, List[str]]]:
@@ -552,7 +556,7 @@ class EnvManager:
         Returns:
             {"package": List[dependencies]}
         """
-        if Path(self.manager).stem != "mamba":
+        if not self.is_mamba():
             self.log.warning(
                 "Package manager '{}' does not support dependency query.".format(
                     self.manager
@@ -585,7 +589,10 @@ class EnvManager:
                 "with_description": bool  # Whether we succeed in get some channeldata.json files
             }
         """
-        ans = await self._execute(self.manager, "search", "--json")
+        if self.is_mamba():
+            ans = await self._execute(self.manager, "repoquery", "search", "*", "--json")
+        else:
+            ans = await self._execute(self.manager, "search", "--json")
         _, output = ans
 
         current_loop = tornado.ioloop.IOLoop.current()
@@ -596,6 +603,23 @@ class EnvManager:
             # dictionary with error info
             return data
 
+        def process_mamba_repoquery_output(data: Dict) -> Dict:
+            """Make a dictionary with keys as packages name and values
+            containing the list of available packages to match the json output
+            of "conda search --json".
+            """
+
+            data_ = collections.defaultdict(lambda : [])
+            for entry in data['result']['pkgs']:
+                name = entry.get('name')
+                if name is not None:
+                    data_[name].append(entry)
+
+            return data_
+
+        if self.is_mamba():
+            data = await current_loop.run_in_executor(None, process_mamba_repoquery_output, data)
+
         def format_packages(data: Dict) -> List:
             packages = []
 
